
ATTS
======

ATTS (Auto Train Test Splitter) splits the given dataframe to train and test without data leakage. It does this with xgboost running in the background. 

Calculates roc_auc scores for the given test size values. Creates a dataframe with these values.
Provides easier change visibility with chart.

## Install
ATTS can be installed using
```
pip install atts
    
